From mboxrd@z Thu Jan 1 00:00:00 1970 Received: from foss.arm.com (foss.arm.com [217.140.110.172]) by smtp.subspace.kernel.org (Postfix) with ESMTP id 40C401A08A3 for ; Tue, 10 Feb 2026 13:28:45 +0000 (UTC) Authentication-Results: smtp.subspace.kernel.org; arc=none smtp.client-ip=217.140.110.172 ARC-Seal:i=1; a=rsa-sha256; d=subspace.kernel.org; s=arc-20240116; t=1770730127; cv=none; b=p9qhZ3Y3GkY3Hah0PYcNHxAcxIcpOH2ylpo6otj6/JRX5gSs+itBP+5eRTRbGDQDD1PPUm2X5VgLkqFJVttq46dsn6oCCHWg5ibA48htX6AzobEagccODja31WxeajzwOqZiwQP1EGgViElsh61UWc7I6J5NLXeFEJqwV5cIe+M= ARC-Message-Signature:i=1; a=rsa-sha256; d=subspace.kernel.org; s=arc-20240116; t=1770730127; c=relaxed/simple; bh=qhoLeiYkDLOdznlHrXM/eR5uFDLkmSSaPYc4hadio7g=; h=Message-ID:Date:MIME-Version:Subject:To:Cc:References:From: In-Reply-To:Content-Type; b=NRls5u06ao3A9RMFYi8mVO+dcUiqPsotubMrykjMlcioIS8wq2N2MxSRd0PTLYqxs31r0VOnqX9X61TuSvDEXtJ8j2UiL8hH8mTDOjMH/a8QmgLicPMg09s0RuwDXaPBIm5Jh9q396DpJ4Vxgl0GZkL/ZTbvDYI8d8mJTDqkNeg= ARC-Authentication-Results:i=1; smtp.subspace.kernel.org; dmarc=pass (p=none dis=none) header.from=arm.com; spf=pass smtp.mailfrom=arm.com; arc=none smtp.client-ip=217.140.110.172 Authentication-Results: smtp.subspace.kernel.org; dmarc=pass (p=none dis=none) header.from=arm.com Authentication-Results: smtp.subspace.kernel.org; spf=pass smtp.mailfrom=arm.com Received: from usa-sjc-imap-foss1.foss.arm.com (unknown [10.121.207.14]) by usa-sjc-mx-foss1.foss.arm.com (Postfix) with ESMTP id 1941C339; Tue, 10 Feb 2026 05:28:38 -0800 (PST) Received: from [10.164.19.61] (unknown [10.164.19.61]) by usa-sjc-imap-foss1.foss.arm.com (Postfix) with ESMTPSA id A55413F63F; Tue, 10 Feb 2026 05:28:40 -0800 (PST) Message-ID: <397482e7-3c89-48e5-9e8c-0798ac92cc05@arm.com> Date: Tue, 10 Feb 2026 18:58:37 +0530 Precedence: bulk X-Mailing-List: linux-kernel@vger.kernel.org List-Id: List-Subscribe: List-Unsubscribe: MIME-Version: 1.0 User-Agent: Mozilla Thunderbird Subject: Re: [PATCH] mm: map maximum pages possible in finish_fault To: Matthew Wilcox Cc: akpm@linux-foundation.org, david@kernel.org, lorenzo.stoakes@oracle.com, Liam.Howlett@oracle.com, vbabka@suse.cz, rppt@kernel.org, surenb@google.com, mhocko@suse.com, linux-mm@kvack.org, linux-kernel@vger.kernel.org, ryan.roberts@arm.com, anshuman.khandual@arm.com, kirill@shutemov.name References: <20260206135648.38164-1-dev.jain@arm.com> Content-Language: en-US From: Dev Jain In-Reply-To: Content-Type: text/plain; charset=UTF-8 Content-Transfer-Encoding: 7bit On 06/02/26 8:52 pm, Matthew Wilcox wrote: > On Fri, Feb 06, 2026 at 07:26:48PM +0530, Dev Jain wrote: >> We test the patch with the following userspace program. A shmem VMA of >> 2M is created, and faulted in, with sysfs setting >> hugepages-2048k/shmem_enabled = always, so that the pagecache is populated >> with a 2M folio. Then, a 64K VMA is created, and we fault on each page. >> Then, we do MADV_DONTNEED to zap the pagetable, so that we can fault again >> in the next iteration. We measure the accumulated time taken during >> faulting the VMA. >> >> On arm64, >> >> without patch: >> Total time taken by inner loop: 4701721766 ns >> >> with patch: >> Total time taken by inner loop: 516043507 ns >> >> giving a 9x improvement. > It's nice that you can construct a test-case that shows improvement, but > is there any real workload that benefits from this? I can try to measure this. But, I constructed that testcase to test the code path, not to show a perf boost (although the boost is obvious enough so why not show it). As I say in the description: "Align finish_fault with filemap_map_pages, and map as many pages as possible, without crossing VMA/PMD/file boundaries." The patch should rather be seen as an extension to 19773df031bc ("mm/fault: try to map the entire file folio in finish_fault()"). The code which my patch removes, was added when the norm was to still perform per-page fault, the argument being, RSS inflation. Perhaps I can polish the patch description so that it clearly mentions what the objective is.